@@ -505,7 +505,7 @@ class ReactionNetworkPout(ReactionNetwork):
 
   '''
 
-  def __init__(self,name=None,modeldir=None):
+  def __init__(self,name="ReactionNetworkPout",modeldir=None):
     '''
 
     Parameters
@@ -648,7 +648,7 @@ class ReactionNetworkPin(ReactionNetwork):
 
   '''
 
-  def __init__(self,name=None,modeldir=None):
+  def __init__(self,name="ReactionNetworkPin",modeldir=None):
     '''
 
     Parameters
