@@ -3,6 +3,8 @@ from __future__ import print_function
 
 import copy
 import math
+import prodimopy.extinction
+import prodimopy.plot_models
 
 from matplotlib.ticker import MaxNLocator
 from scipy.interpolate import interp1d
@@ -12,8 +14,6 @@ import matplotlib as mpl
 import matplotlib.colors as mcolors
 import matplotlib.pyplot as plt
 import numpy as np
-import prodimopy.extinction
-import prodimopy.plot_models
 
 
 # has to be this way because of circular imports
@@ -464,7 +464,7 @@ class Plot(object):
       y=np.copy(model.z)*scalexy[1]
       # if one wants log scale on the y axis (height) avoid problems with
       # z=0.0 in thee prodimo grid.
-      if zlog==True:
+      if "ylog" in kwargs and kwargs["ylog"]==True:
         y[:,0]=y[:,0]+np.min(y[:,1])*scalexy[1]
       ax.set_ylabel("z [au]")
       ax.set_xlabel("r [au]")
