@@ -222,6 +222,11 @@ class slab_data:
         """ list:
         It stores the convolved frequency grid of all line overlap models
         """
+        
+        self._convOverlapWav=None
+        """ list:
+        It stores the convolved wavelength grid of all line overlap models
+        """
 
         self._convOverlapLTEflux=None
         """ list:
@@ -273,8 +278,8 @@ class slab_data:
         output+="\n NModels: "
         output+=str(self.nmodels)
         if isinstance(self.directory,list):
-            for i in self.directory
-            output+="\n\n Directory: "+i
+            for i in self.directory:
+                output+="\n\n Directory: "+i
         else:
             output+="\n\n Directory: "+self.directory
         return output
@@ -1083,6 +1088,21 @@ class slab_data:
     @convOverlapFreq.setter
     def convOverlapFreq(self,value):
         self._convOverlapFreq=value
+
+
+    @property
+    def convOverlapWave(self):
+        if self.nmodels>1:
+            self._convOverlapWave=[]
+            for i in range(self.nmodels):
+                self._convOverlapWave.append(self.models[i].convOverlapWave)
+        else:
+            self._convOverlapWave=self.models[0].convOverlapWave
+        return self._convOverlapWave
+
+    @convOverlapWave.setter
+    def convOverlapWave(self,value):
+        self._convOverlapWave=value
         
     @property
     def overlapFreq(self):
@@ -1251,6 +1271,7 @@ class slab:
         self.convOverlapLTE=None
         self.convOverlapNLTE=None
         self.convOverlapFreq=None
+        self.convOverlapWave=None
         self.convOverlapR=1e5
         self.overlapR=1e5
 
@@ -1334,6 +1355,7 @@ class slab:
         self.convOverlapLTE=apy_convolve(self.overlapLTE[mask],g)
         # self.convOverlapNLTE=apy_convolve(self.overlapNLTE[mask],g)
         self.convOverlapFreq=self.overlapFreq[mask]*1.0
+        self.convOverlapWave=c/self.convOverlapFreq*1e-3
         self.convOverlapR = R
 
     def show(self):
